.. _tutorial_more_widgets:

More on |Enaml| Widgets
===============================================================================

In this tutorial, we take a closer look at some of the widgets available for
building GUI's in |Enaml| by building on the :ref:`John Doe tutorial
<john-doe>`. We will explore some of the things you can do with widgets that
you can't do or that are hard to do in other GUI builders.


